<?php
/*
Plugin Name: Access Manager for Publishing
Description: A plugin to control who can publish posts and products.
Version: 1.2
Author: Ali Motlaghian
License: GPLv2 or later
License URI: https://www.gnu.org/licenses/gpl-2.0.html
Text Domain: access-manager-for-publishing
Domain Path: /languages
*/


if (!defined('ABSPATH')) {
    exit; // Exit if accessed directly.
}

class Access_Control_Plugin {
    private $is_rtl = false;

    public function __construct() {
        $this->is_rtl = (get_locale() === 'fa_IR'); 
        add_action('admin_menu', [$this, 'add_settings_page']);
        add_action('admin_init', [$this, 'register_settings']);
        add_filter('map_meta_cap', [$this, 'restrict_publish_capabilities'], 10, 4);
        add_action('admin_footer', [$this, 'disable_publish_button']);
    }

    public function add_settings_page() {
        add_options_page(
            $this->translate('Access', 'دسترسی'),
            $this->translate('Access', 'دسترسی'),
            'manage_options',
            'access-control-settings',
            [$this, 'settings_page_html']
        );
    }

    public function register_settings() {
        register_setting('access_control_settings', 'allowed_publishers');
    }

    public function settings_page_html() {
        if (!current_user_can('manage_options')) {
            return;
        }

        $users = get_users(['role__in' => ['administrator', 'editor', 'author', 'shop_manager']]);
        $allowed_publishers = get_option('allowed_publishers', []);

        echo '<div class="wrap">';
        echo '<h1>' . $this->translate('Who can publish content?', 'چه کسی حق ارسال مطالب را داشته باشد') . '</h1>';
        echo '<form method="post" action="options.php">';
        settings_fields('access_control_settings');
        echo '<table class="form-table">';
        
        foreach ($users as $user) {
            $checked = in_array($user->ID, $allowed_publishers) ? 'checked' : '';
            echo '<tr>';
            echo '<th scope="row">' . esc_html($user->display_name) . '</th>';
            echo '<td><input type="checkbox" name="allowed_publishers[]" value="' . esc_attr($user->ID) . '" ' . $checked . '></td>';
            echo '</tr>';
        }

        echo '</table>';
        submit_button($this->translate('Save Changes', 'ذخیره تغییرات'));
        echo '</form>';
        echo '</div>';
    }

    public function restrict_publish_capabilities($caps, $cap, $user_id, $args) {
        $allowed_publishers = get_option('allowed_publishers', []);

        if (!in_array($user_id, $allowed_publishers)) {
            if (in_array($cap, ['publish_posts', 'publish_product', 'publish_pages'])) {
                $caps[] = 'do_not_allow';
            }
        }

        return $caps;
    }

    public function disable_publish_button() {
        $allowed_publishers = get_option('allowed_publishers', []);

        if (!in_array(get_current_user_id(), $allowed_publishers)) {
            echo '
            <script type="text/javascript">
                jQuery(document).ready(function($) {
                    if ($("#post").length > 0) {
                        $("#publish").attr("disabled", "disabled").val("' . esc_js($this->translate('Only saving as draft is possible', 'فقط ذخیره به عنوان پیش‌نویس ممکن است')) . '");
                    }
                });
            </script>';
        }
    }

    private function translate($en, $fa) {
        return $this->is_rtl ? $fa : $en;
    }
}

new Access_Control_Plugin();
